Creates bubble plots for all continuous moderators in a meta-regression.
Arguments
- object
A
bayesma_regobject.- ncol
Integer. Number of columns in the plot grid (default: 2).
- ...
Additional arguments passed to
bubble_plot().
Creates bubble plots for all continuous moderators in a meta-regression.
A bayesma_reg object.
Integer. Number of columns in the plot grid (default: 2).
Additional arguments passed to bubble_plot().